@@ -74,7 +74,7 @@ static const int maxprecision = 1000;
 
 KCalculator::KCalculator(QWidget *parent)
         : KXmlGuiWindow(parent), shift_mode_(false), hyp_mode_(false),
-        memory_num_(0.0), constants_(0), core()
+        memory_num_(0.0), constants_menu_(0), constants_(0), core()
 {
     /* central widget to contain all the elements */
     QWidget *const central = new QWidget(this);
@@ -120,10 +120,8 @@ KCalculator::KCalculator(QWidget *parent)
 
     // additional menu setup
 
-    KCalcConstMenu *const tmp_menu = new KCalcConstMenu(i18n("&Constants"), this);
-    menuBar()->insertMenu((menuBar()->actions)()[2], tmp_menu);
-    connect(tmp_menu, SIGNAL(triggeredConstant(science_constant)),
-            this, SLOT(slotConstantToDisplay(science_constant)));
+    constants_menu_ = createConstantsMenu();
+    menuBar()->insertMenu((menuBar()->actions)()[2], constants_menu_);
 
     // misc setup
 
@@ -192,31 +190,31 @@ void KCalculator::setupMainActions()
 
     // mode menu
     QActionGroup *modeGroup = new QActionGroup(this);
-    action_mode_simple_ = actionCollection()->add<KToggleAction>(QLatin1String( "mode_simple" ));
+    action_mode_simple_ = actionCollection()->add<KToggleAction>(QLatin1String("mode_simple"));
     action_mode_simple_->setActionGroup(modeGroup);
     action_mode_simple_->setText(i18n("Simple Mode"));
     connect(action_mode_simple_, SIGNAL(toggled(bool)), SLOT(slotSetSimpleMode()));
-    action_mode_science_ = actionCollection()->add<KToggleAction>(QLatin1String( "mode_science" ));
+    action_mode_science_ = actionCollection()->add<KToggleAction>(QLatin1String("mode_science"));
     action_mode_science_->setActionGroup(modeGroup);
     action_mode_science_->setText(i18n("Science Mode"));
     connect(action_mode_science_, SIGNAL(toggled(bool)), SLOT(slotSetScienceMode()));
-    action_mode_statistic_ = actionCollection()->add<KToggleAction>(QLatin1String( "mode_statistics" ));
+    action_mode_statistic_ = actionCollection()->add<KToggleAction>(QLatin1String("mode_statistics"));
     action_mode_statistic_->setActionGroup(modeGroup);
     action_mode_statistic_->setText(i18n("Statistic Mode"));
     connect(action_mode_statistic_, SIGNAL(toggled(bool)), SLOT(slotSetStatisticMode()));
-    action_mode_numeral_ = actionCollection()->add<KToggleAction>(QLatin1String( "mode_numeral" ));
+    action_mode_numeral_ = actionCollection()->add<KToggleAction>(QLatin1String("mode_numeral"));
     action_mode_numeral_->setActionGroup(modeGroup);
     action_mode_numeral_->setText(i18n("Numeral System Mode"));
     connect(action_mode_numeral_, SIGNAL(toggled(bool)), SLOT(slotSetNumeralMode()));
 
     // settings menu
-    action_constants_show_ = actionCollection()->add<KToggleAction>(QLatin1String( "show_constants" ));
-    action_constants_show_->setText(i18n("&Constants Buttons"));
+    action_constants_show_ = actionCollection()->add<KToggleAction>(QLatin1String("show_constants"));
+    action_constants_show_->setText(i18n("Constants &Buttons"));
     action_constants_show_->setChecked(true);
     connect(action_constants_show_, SIGNAL(toggled(bool)),
             SLOT(slotConstantsShow(bool)));
 
-    action_bitset_show_ = actionCollection()->add<KToggleAction>(QLatin1String( "show_bitset" ));
+    action_bitset_show_ = actionCollection()->add<KToggleAction>(QLatin1String("show_bitset"));
     action_bitset_show_->setText(i18n("Show B&it Edit"));
     action_bitset_show_->setChecked(true);
     connect(action_bitset_show_, SIGNAL(toggled(bool)),
@@ -227,19 +225,25 @@ void KCalculator::setupMainActions()
                                  actionCollection());
 }
 
+KCalcConstMenu *KCalculator::createConstantsMenu() {
+    KCalcConstMenu *menu = new KCalcConstMenu(i18n("&Constants"), this);
+    connect(menu, SIGNAL(triggeredConstant(science_constant)), this, SLOT(slotConstantToDisplay(science_constant)));
+	return menu;
+}
+
 void KCalculator::setupStatusbar()
 {
     // Status bar contents
-    statusBar()->insertPermanentFixedItem(QLatin1String( " NORM " ), ShiftField);
+    statusBar()->insertPermanentFixedItem(QLatin1String(" NORM "), ShiftField);
     statusBar()->setItemAlignment(ShiftField, Qt::AlignCenter);
 
-    statusBar()->insertPermanentFixedItem(QLatin1String( " HEX " ), BaseField);
+    statusBar()->insertPermanentFixedItem(QLatin1String(" HEX "), BaseField);
     statusBar()->setItemAlignment(BaseField, Qt::AlignCenter);
 
-    statusBar()->insertPermanentFixedItem(QLatin1String( " DEG " ), AngleField);
+    statusBar()->insertPermanentFixedItem(QLatin1String(" DEG "), AngleField);
     statusBar()->setItemAlignment(AngleField, Qt::AlignCenter);
 
-    statusBar()->insertPermanentFixedItem(QLatin1String( " \xa0\xa0 " ), MemField);   // nbsp
+    statusBar()->insertPermanentFixedItem(QLatin1String(" \xa0\xa0 "), MemField);   // nbsp
     statusBar()->setItemAlignment(MemField, Qt::AlignCenter);
 }
 
@@ -310,6 +314,16 @@ void KCalculator::setupKeys()
             SLOT(slotShifttoggled(bool)));
     connect(this, SIGNAL(switchShowAccels(bool)),
             pbShift, SLOT(slotSetAccelDisplayMode(bool)));
+			
+			
+			
+    pbBackspace->setShortcut(QKeySequence(Qt::Key_Backspace));
+    new QShortcut(Qt::Key_PageUp, pbBackspace, SLOT(animateClick()));
+    connect(pbBackspace, SIGNAL(clicked()),
+            SLOT(slotBackspaceclicked()));
+    connect(this, SIGNAL(switchShowAccels(bool)),
+            pbBackspace, SLOT(slotSetAccelDisplayMode(bool)));
+			
 
     pbClear->setShortcut(QKeySequence(Qt::Key_Escape));
     new QShortcut(Qt::Key_PageUp, pbClear, SLOT(animateClick()));
@@ -377,7 +391,7 @@ void KCalculator::setupKeys()
     // numeric keypad
 
     pbCube->addMode(ModeNormal, i18nc("Third power", "x<sup>3</sup>"), i18n("Third power"));
-    pbCube->addMode(ModeShift, QLatin1String( "<sup>3</sup>&radic;x" ), i18n("Cube root"));
+    pbCube->addMode(ModeShift, QLatin1String("<sup>3</sup>&radic;x"), i18n("Cube root"));
     connect(pbCube, SIGNAL(clicked()),
             SLOT(slotCubeclicked()));
     connect(this, SIGNAL(switchShowAccels(bool)),
@@ -414,9 +428,9 @@ void KCalculator::setupKeys()
 
     pbPeriod->setText(KGlobal::locale()->decimalSymbol());
     pbPeriod->setShortcut(KGlobal::locale()->decimalSymbol());
-    if (KGlobal::locale()->decimalSymbol() == QLatin1String( "." ))
+    if (KGlobal::locale()->decimalSymbol() == QLatin1String("."))
         new QShortcut(Qt::Key_Comma, pbPeriod, SLOT(animateClick()));
-    else if (KGlobal::locale()->decimalSymbol() == QLatin1String( "," ))
+    else if (KGlobal::locale()->decimalSymbol() == QLatin1String(","))
         new QShortcut(Qt::Key_Period, pbPeriod, SLOT(animateClick()));
     connect(pbPeriod, SIGNAL(clicked()),
             SLOT(slotPeriodclicked()));
@@ -552,7 +566,7 @@ void KCalculator::setupKeys()
 
     pbMean->addMode(ModeNormal, i18nc("Mean", "Mea"), i18n("Mean"));
     pbMean->addMode(ModeShift, QString::fromUtf8("\xce\xa3")
-                    + QLatin1String( "x<sup>2</sup>" ),
+                    + QLatin1String("x<sup>2</sup>"),
                     i18n("Sum of all data items squared"));
     connect(this, SIGNAL(switchShowAccels(bool)),
             pbMean, SLOT(slotSetAccelDisplayMode(bool)));
@@ -560,9 +574,9 @@ void KCalculator::setupKeys()
             pbMean, SLOT(slotSetMode(ButtonModeFlags,bool)));
     connect(pbMean, SIGNAL(clicked()), SLOT(slotStatMeanclicked()));
 
-    pbSd->addMode(ModeNormal, QString::fromUtf8("σ", -1) + QLatin1String( "<sub>N</sub>" ),
+    pbSd->addMode(ModeNormal, QString::fromUtf8("σ", -1) + QLatin1String("<sub>N</sub>"),
                   i18n("Standard deviation"));
-    pbSd->addMode(ModeShift, QString::fromUtf8("σ", -1) + QLatin1String( "<sub>N-1</sub>" ),
+    pbSd->addMode(ModeShift, QString::fromUtf8("σ", -1) + QLatin1String("<sub>N-1</sub>"),
                   i18n("Sample standard deviation"));
     connect(this, SIGNAL(switchShowAccels(bool)),
             pbSd, SLOT(slotSetAccelDisplayMode(bool)));
@@ -665,7 +679,7 @@ void KCalculator::setupKeys()
     connect(pbFactorial, SIGNAL(clicked()), SLOT(slotFactorialclicked()));
 
     pbSquare->addMode(ModeNormal, i18nc("Square", "x<sup>2</sup>"), i18n("Square"));
-    pbSquare->addMode(ModeShift, QLatin1String( "&radic;x" ), i18n("Square root"));
+    pbSquare->addMode(ModeShift, QLatin1String("&radic;x"), i18n("Square root"));
     pbSquare->setShortcut(QKeySequence(Qt::Key_BracketLeft));
     new QShortcut(Qt::Key_twosuperior, pbSquare, SLOT(animateClick()));
     connect(this, SIGNAL(switchShowAccels(bool)),
@@ -683,7 +697,7 @@ void KCalculator::setupKeys()
     pbPower->setShortcut(QKeySequence(Qt::Key_AsciiCircum));
     connect(pbPower, SIGNAL(clicked()), SLOT(slotPowerclicked()));
 
-    pbEE->addMode(ModeNormal, QLatin1String( "x<small>" "\xb7" "10</small><sup>y</sup>" ),
+    pbEE->addMode(ModeNormal, QLatin1String("x<small>" "\xb7" "10</small><sup>y</sup>"),
                   i18n("Exponent"));
     connect(this, SIGNAL(switchShowAccels(bool)),
             pbEE, SLOT(slotSetAccelDisplayMode(bool)));
@@ -704,6 +718,7 @@ void KCalculator::setupKeys()
     function_button_list_.append(pbSquare);
     function_button_list_.append(pbLn);
     function_button_list_.append(pbPower);
+    function_button_list_.append(pbCube);
 
     mem_button_list_.append(pbMemRecall);
     mem_button_list_.append(pbMemPlusMinus);
@@ -728,12 +743,11 @@ void KCalculator::setupKeys()
     operation_button_list_.append(pbPercent);
     operation_button_list_.append(pbCmp);
     operation_button_list_.append(pbMod);
-    operation_button_list_.append(pbCube);
 }
 
 void KCalculator::updateGeometry()
 {
-    const QSize em = pbAND->fontMetrics().size(0, QLatin1String( "M" ));
+    const QSize em = pbAND->fontMetrics().size(0, QLatin1String("M"));
     int margin =
         QApplication::style()->pixelMetric(QStyle::PM_ButtonMargin, 0, 0);
     margin = qMax(qMin(margin / 2, 3), 3);
@@ -750,7 +764,8 @@ void KCalculator::updateGeometry()
     // right pad
 
     foreach(QObject *obj, rightPad->children()) {
-        if (KCalcButton *const button = qobject_cast<KCalcButton*>(obj)) {
+        KCalcButton *const button = qobject_cast<KCalcButton*>(obj);
+        if (button && button != pbShift) {
             button->setFixedWidth(em.width()*3 + margin*2);
             button->installEventFilter(this);
         }
@@ -770,7 +785,7 @@ void KCalculator::updateGeometry()
 
 void KCalculator::slotConstantToDisplay(const science_constant &const_chosen)
 {
-    calc_display->setAmount(const_chosen.value);
+    calc_display->setAmount(KNumber(const_chosen.value));
     updateDisplay(0);
 }
 
@@ -782,27 +797,27 @@ void KCalculator::slotBaseSelected(int base)
     switch (base) {
     case BinMode:
         current_base = calc_display->setBase(NumBase(2));
-        statusBar()->changeItem(QLatin1String( "BIN" ), BaseField);
-        calc_display->setStatusText(BaseField, QLatin1String( "Bin" ));
+        statusBar()->changeItem(QLatin1String("BIN"), BaseField);
+        calc_display->setStatusText(BaseField, QLatin1String("Bin"));
         break;
     case OctMode:
         current_base = calc_display->setBase(NumBase(8));
-        statusBar()->changeItem(QLatin1String( "OCT" ), BaseField);
-        calc_display->setStatusText(BaseField, QLatin1String( "Oct" ));
+        statusBar()->changeItem(QLatin1String("OCT"), BaseField);
+        calc_display->setStatusText(BaseField, QLatin1String("Oct"));
         break;
     case DecMode:
         current_base = calc_display->setBase(NumBase(10));
-        statusBar()->changeItem(QLatin1String( "DEC" ), BaseField);
-        calc_display->setStatusText(BaseField, QLatin1String( "Dec" ));
+        statusBar()->changeItem(QLatin1String("DEC"), BaseField);
+        calc_display->setStatusText(BaseField, QLatin1String("Dec"));
         break;
     case HexMode:
         current_base = calc_display->setBase(NumBase(16));
-        statusBar()->changeItem(QLatin1String( "HEX" ), BaseField);
-        calc_display->setStatusText(BaseField, QLatin1String( "Hex" ));
+        statusBar()->changeItem(QLatin1String("HEX"), BaseField);
+        calc_display->setStatusText(BaseField, QLatin1String("Hex"));
         break;
     default:
-        statusBar()->changeItem(QLatin1String( "Error" ), BaseField);
-        calc_display->setStatusText(BaseField, QLatin1String( "Error" ));
+        statusBar()->changeItem(QLatin1String("Error"), BaseField);
+        calc_display->setStatusText(BaseField, QLatin1String("Error"));
         return;
     }
 
@@ -858,16 +873,16 @@ void KCalculator::slotAngleSelected(int mode)
     angle_mode_ = mode;
     switch (mode) {
     case DegMode:
-        statusBar()->changeItem(QLatin1String( "DEG" ), AngleField);
-        calc_display->setStatusText(AngleField, QLatin1String( "Deg" ));
+        statusBar()->changeItem(QLatin1String("DEG"), AngleField);
+        calc_display->setStatusText(AngleField, QLatin1String("Deg"));
         break;
     case RadMode:
-        statusBar()->changeItem(QLatin1String( "RAD" ), AngleField);
-        calc_display->setStatusText(AngleField, QLatin1String( "Rad" ));
+        statusBar()->changeItem(QLatin1String("RAD"), AngleField);
+        calc_display->setStatusText(AngleField, QLatin1String("Rad"));
         break;
     case GradMode:
-        statusBar()->changeItem(QLatin1String( "GRA" ), AngleField);
-        calc_display->setStatusText(AngleField, QLatin1String( "Gra" ));
+        statusBar()->changeItem(QLatin1String("GRA"), AngleField);
+        calc_display->setStatusText(AngleField, QLatin1String("Gra"));
         break;
     default: // we shouldn't ever end up here
         angle_mode_ = RadMode;
@@ -919,8 +934,8 @@ void KCalculator::slotMemStoreclicked()
     EnterEqual();
 
     memory_num_ = calc_display->getAmount();
-    calc_display->setStatusText(MemField, QLatin1String( "M" ));
-    statusBar()->changeItem(QLatin1String( "M" ), MemField);
+    calc_display->setStatusText(MemField, QLatin1String("M"));
+    statusBar()->changeItem(QLatin1String("M"), MemField);
     pbMemRecall->setEnabled(true);
 }
 
@@ -1162,11 +1177,16 @@ void KCalculator::slotPowerclicked()
 void KCalculator::slotMemClearclicked()
 {
     memory_num_  = 0;
-    statusBar()->changeItem(QLatin1String( " \xa0\xa0 " ), MemField);
+    statusBar()->changeItem(QLatin1String(" \xa0\xa0 "), MemField);
     calc_display->setStatusText(MemField, QString());
     pbMemRecall->setDisabled(true);
 }
 
+void KCalculator::slotBackspaceclicked()
+{
+    calc_display->deleteLastDigit();
+}
+
 void KCalculator::slotClearclicked()
 {
     calc_display->sendEvent(KCalcDisplay::EventClear);
@@ -1395,7 +1415,7 @@ void KCalculator::slotConstclicked(int button)
 
     if (!shift_mode_) {
         // set the display to the configured value of constant button
-        calc_display->setAmount(btn->constant());
+        calc_display->setAmount(KNumber(btn->constant()));
     } else {
         pbShift->setChecked(false);
         KCalcSettings::setValueConstant(button, calc_display->text());
@@ -1413,28 +1433,28 @@ void KCalculator::showSettings()
 {
     // Check if there is already a dialog and if so bring
     // it to the foreground.
-    if (KConfigDialog::showDialog(QLatin1String( "settings" )))
+    if (KConfigDialog::showDialog(QLatin1String("settings")))
         return;
 
     // Create a new dialog with the same name as the above checking code.
-    KConfigDialog *dialog = new KConfigDialog(this, QLatin1String( "settings" ), KCalcSettings::self());
+    KConfigDialog *dialog = new KConfigDialog(this, QLatin1String("settings"), KCalcSettings::self());
     dialog->showButtonSeparator(true);
 
     // general settings
 
     General *general = new General(0);
     general->kcfg_Precision->setMaximum(maxprecision);
-    dialog->addPage(general, i18n("General"), QLatin1String( "accessories-calculator" ), i18n("General Settings"));
+    dialog->addPage(general, i18n("General"), QLatin1String("accessories-calculator"), i18n("General Settings"));
 
     // font settings
 
     Fonts *fonts = new Fonts(0);
-    dialog->addPage(fonts, i18n("Font"), QLatin1String( "preferences-desktop-font" ), i18n("Select Display Font"));
+    dialog->addPage(fonts, i18n("Font"), QLatin1String("preferences-desktop-font"), i18n("Select Display Font"));
 
     // color settings
 
     Colors *color = new Colors(0);
-    dialog->addPage(color, i18n("Colors"), QLatin1String( "format-fill-color" ), i18n("Button & Display Colors"));
+    dialog->addPage(color, i18n("Colors"), QLatin1String("format-fill-color"), i18n("Button & Display Colors"));
 
     // constant settings
 
@@ -1483,7 +1503,7 @@ void KCalculator::showSettings()
             SLOT(slotChooseScientificConst5(science_constant)));
     constants_->pushButton5->setMenu(tmp_menu);
 
-    dialog->addPage(constants_, i18n("Constants"), QLatin1String( "preferences-kcalc-constants_" ), i18n("Define Constants"));
+    dialog->addPage(constants_, i18n("Constants"), QLatin1String("preferences-kcalc-constants_"), i18n("Define Constants"));
 
     // When the user clicks OK or Apply we want to update our settings.
     connect(dialog, SIGNAL(settingsChanged(QString)), SLOT(updateSettings()));
@@ -1544,9 +1564,25 @@ void KCalculator::slotSetSimpleMode()
     action_constants_show_->setEnabled(false);
     action_bitset_show_->setChecked(false);
     action_bitset_show_->setEnabled(false);
+    showMemButtons(false);
     showScienceButtons(false);
     showStatButtons(false);
     showLogicButtons(false);
+    // hide some individual buttons, which are not in one of the above groups
+    pbShift->hide();
+    pbMod->hide();
+    pbReci->hide();
+    pbFactorial->hide();
+    pbSquare->hide();
+    pbPower->hide();
+    pbCube->hide();
+	pbBackspace->hide();
+    pbEE->hide();
+	
+	
+	delete constants_menu_;
+	constants_menu_ = 0;
+	
     KCalcSettings::setCalculatorMode(KCalcSettings::EnumCalculatorMode::simple);
 }
 
@@ -1556,9 +1592,27 @@ void KCalculator::slotSetScienceMode()
     action_constants_show_->setChecked(KCalcSettings::showConstants());
     action_bitset_show_->setChecked(false);
     action_bitset_show_->setEnabled(false);
+    // show some individual buttons
+    pbShift->show();
+    pbMod->show();
+    pbReci->show();
+    pbFactorial->show();
+    pbSquare->show();
+    pbPower->show();
+    pbCube->show();
+	pbBackspace->show();
+    pbEE->show();
+    // show or hide some groups of buttons
+    showMemButtons(true);
     showScienceButtons(true);
     showStatButtons(false);
     showLogicButtons(false);
+	
+	if(!constants_menu_) {
+		constants_menu_ = createConstantsMenu();
+	    menuBar()->insertMenu((menuBar()->actions)()[2], constants_menu_);
+	}
+	
     KCalcSettings::setCalculatorMode(KCalcSettings::EnumCalculatorMode::science);
 }
 
@@ -1568,9 +1622,25 @@ void KCalculator::slotSetStatisticMode()
     action_constants_show_->setChecked(KCalcSettings::showConstants());
     action_bitset_show_->setChecked(false);
     action_bitset_show_->setEnabled(false);
+    pbShift->show();
+    pbMod->show();
+    pbReci->show();
+    pbFactorial->show();
+    pbSquare->show();
+    pbPower->show();
+    pbCube->show();
+	pbBackspace->show();
+    pbEE->show();
+    showMemButtons(true);
     showScienceButtons(true);
     showStatButtons(true);
     showLogicButtons(false);
+	
+	if(!constants_menu_) {
+		constants_menu_ = createConstantsMenu();
+	    menuBar()->insertMenu((menuBar()->actions)()[2], constants_menu_);
+	}
+	
     KCalcSettings::setCalculatorMode(KCalcSettings::EnumCalculatorMode::statistics);
 }
 
@@ -1580,12 +1650,44 @@ void KCalculator::slotSetNumeralMode()
     action_constants_show_->setEnabled(false);
     action_bitset_show_->setEnabled(true);
     action_bitset_show_->setChecked(KCalcSettings::showBitset());
+    pbShift->show();
+    pbMod->show();
+    pbReci->show();
+    pbFactorial->show();
+    pbSquare->show();
+    pbPower->show();
+    pbCube->show();
+	pbBackspace->show();
+    pbEE->show();
+    showMemButtons(true);
     showScienceButtons(false);
     showStatButtons(false);
     showLogicButtons(true);
+	
+	if(!constants_menu_) {
+		constants_menu_ = createConstantsMenu();
+	    menuBar()->insertMenu((menuBar()->actions)()[2], constants_menu_);
+	}
+	
     KCalcSettings::setCalculatorMode(KCalcSettings::EnumCalculatorMode::numeral);
 }
 
+void KCalculator::showMemButtons(bool toggled)
+{
+    if (toggled) {
+        foreach(QAbstractButton *btn, mem_button_list_) {
+            btn->show();
+        }
+    } else {
+        foreach(QAbstractButton *btn, mem_button_list_) {
+            btn->hide();
+        }
+        // these are in the mem_button_list_ but should not be hidden
+        pbClear->show();
+        pbAllClear->show();
+    }
+}
+
 void KCalculator::showStatButtons(bool toggled)
 {
     if (toggled) {
@@ -1608,8 +1710,9 @@ void KCalculator::showScienceButtons(bool toggled)
         foreach(QAbstractButton* btn, angle_choose_group_->buttons()) {
             btn->show();
         }
-        statusBar()->setItemFixed(AngleField, -1);
         setAngle();
+        statusBar()->setItemFixed(AngleField, -1);
+
     } else {
         foreach(QAbstractButton* btn, scientific_buttons_) {
             btn->hide();
@@ -1634,9 +1737,10 @@ void KCalculator::showLogicButtons(bool toggled)
         foreach(QAbstractButton* btn, logic_buttons_) {
             btn->show();
         }
-        statusBar()->setItemFixed(BaseField, -1);
-        setBase();
 
+		setBase();
+		statusBar()->setItemFixed(BaseField, -1);
+        
         foreach(QAbstractButton *btn, base_choose_group_->buttons()) {
             btn->show();
         }
@@ -1755,7 +1859,7 @@ void KCalculator::setColors()
         return;
     }
 
-    QString sheet = QLatin1String( "KPushButton { background-color: %1 }" );
+    QString sheet = QLatin1String("KPushButton { background-color: %1 }");
 
     QColor numPal(KCalcSettings::numberButtonsColor());
     for (int i = 0; i < 10; i++) {
@@ -1850,7 +1954,7 @@ bool KCalculator::eventFilter(QObject *o, QEvent *e)
         QColor c = KColorMimeData::fromMimeData(ev->mimeData());
         if (c.isValid()) {
             QString cn = c.name();
-            QString sheet = QLatin1String( "background-color: %1" );
+            QString sheet = QLatin1String("background-color: %1");
 
             QList<QAbstractButton*> *list;
             int num_but;
@@ -1923,7 +2027,7 @@ extern "C" KDE_EXPORT int kdemain(int argc, char *argv[])
     aboutData.addAuthor(ki18n("Michel Marti"), KLocalizedString(), "mma@objectxp.com");
     aboutData.addAuthor(ki18n("David Johnson"), KLocalizedString(), "david@usermode.org");
 
-    aboutData.setProgramIconName(QLatin1String( "accessories-calculator" ));
+    aboutData.setProgramIconName(QLatin1String("accessories-calculator"));
 
     KCmdLineArgs::init(argc, argv, &aboutData);
 
